WHATS_NEW = """
# 更新日志
## kaa
### v2025.3.9
脚本：
* [修复] 修复部分情况下工作分配偶像选择页面报错（#a35e6c3）
* [修复] 修复培育中强化技能卡时有几率卡在确认按钮上（#221721a）
* [新增] 支持指定培育中行动优先级（#fc8c456）
* [新增] 支持处理培育结束时的未读交流（#452ba67）
* [新增] 培育中支持优先选择 SP 课程（#ee3808c）
* [新增] 培育中文化课（授業）行动支持处理自习事件（#47287fd）

界面：
* [新增] UI 上实时展示设备画面（#72a1a17）

框架：
* [修复] 修复调试模式下内存中截图数据不会释放的问题（#bead31a）
* [修复] 修复启动模拟器前不会自动检测是否已启动的问题（#71d75b7）
* [修复] 修复若软件处于中文目录，读取图片资源失败的问题（#a8aee32）
* [新增] 降低双击默认速度（#e63ad2d）
* [新增] 支持启动 kaa 前自动启动模拟器（#8ee51ba）
* [重构] 移动 grayscaled 和 unify_image 函数的位置（#500e11d）
* [重构] 移动 util 模块位置（#0d3e5de）
* [重构] 移除原有 kotonebot.run 模块中函数，改用 Kotonebot 类（#508d81c）

开发工具：
* [修复] 修复写出 dumps 文件时的编码问题（#d5c64df）
* [新增] 优化 DumpViewer 调用堆栈部分与时间部分的显示（#41d4c4c）
* [新增] ImageAnnotation 新增 description 字段（#425057d）
* [新增] DumpViewer 新增滚动锁定按钮（#79927a7）
* [新增] DumpViewer 两次结果之间新增时间差显示（#e3583f2）
* [重构] 将调试 WS 消息体提取为 pydantic Model（#abf7fbc）

其他：
* [其他] R.py 中的 HintBox 类型的注释也加入裁剪后图片的展示（#7907e44）

### v2025.3.1.0
脚本：
* [新增] 新增支持指定回忆编成编号（#6482962）
* [新增] 优化培育与日常流程，修复一些 bug（#145f97f）
* [新增] 支持处理外出行动 & 优化部分流程（#03fdfaa）
* [新增] 新增支持处理技能卡强化选择事件（#133f084）
* [新增] 培育中支持识别睡意 T 卡（眠気）（#5a68500）
* [修复] 修复课程中无法处理当前回合无剩余手牌的情况（#bfb574c）
* [修复] 修复课程中遇到四/五张手牌时会卡住的问题（#ae22253）
* [修复] 修复某些情况下会卡在培育开始第二步（#73dc4d8）
* [修复] 修复某些情况下会卡在工作分配偶像选择页面（#2ff655f）

界面：
* [新增] UI 上新增更新日志 Tab（#07be7b3）
* [新增] 新增一键上传日志报告功能（#62d5805）

框架：
* [新增] device.click() 方法新增支持传入 tuple[int, int]（#f146038）
* [新增] adb_raw 截图方法加入超时自动重试（#08f382c）
* [新增] 为 device.click() 方法添加可视调试信息（#be37164）
* [新增] 为 adb_raw 截图方式的截图线程加入自动重试（#9b25098）
* [修复] 修复了 device.click() 调试信息在没有截图数据时会报错（#f0a3baa）
* [修复] 修复写入调试数据前不会自动清空上次数据的问题（#80e04ee）

其他：
* [新增] ImageAnntation 页面与 Python 代码引入 HintPoint 支持（#949e28d）
* [修复] 修复某些情况下会卡在领取任务奖励处（#f80660e）
* [单测] 移除无用单元测试（#54f9b03）

### v2025.2.23.0
修复：
* 返回首页时无法处理弹出某些弹窗
* 培育中，某些情况下会卡在饮料领取弹窗
* 培育中，某些情况下会在饮料领取时报错

新增：
* 支持处理游戏本体更新弹窗
* 培育中，支持处理技能卡移除事件
* 培育结束时，支持处理“偶像强化月”活动的新纪录弹窗
* UI 标题上新增版本号显示

### v2025.2.20.1
修复：
* ADB 设备连接失败的问题

### v2025.2.20.0
初始版本。
"""



from kotonebot.tasks.common import sprite_path
from kotonebot.backend.core import Image, HintBox, HintPoint



class Common:
    
    ButtonClose = Image(path=sprite_path(r"9aab23b5-7c17-48fa-86ed-84b59e12b7da.png"), name="button_close.png")

    ButtonCommuFastforward = Image(path=sprite_path(r"a51fd16e-2611-49d7-8baf-24332aab9174.png"), name="button_commu_fastforward.png")

    ButtonCommuSkip = Image(path=sprite_path(r"e674f5ba-e5eb-4ad0-b3dc-b95af4fdee47.png"), name="button_commu_skip.png")

    ButtonCompletion = Image(path=sprite_path(r"249ea819-b78b-4dde-b1c0-ac5522c283fa.png"), name="button_completion.png")

    ButtonConfirm = Image(path=sprite_path(r"b549771d-c155-4f5b-be39-2fa2d97b7250.png"), name="button_confirm.png")

    ButtonConfirmNoIcon = Image(path=sprite_path(r"1db90fe6-0e91-4524-86fe-56da141f97de.png"), name="button_confirm_no_icon.png")

    ButtonContest = Image(path=sprite_path(r"82b63d02-98d0-49dd-add6-01f86dd14733.png"), name="button_contest.png")

    ButtonEnd = Image(path=sprite_path(r"29ab0880-7fbc-4fce-b31a-c911d63f8c31.png"), name="button_end.png")

    ButtonHome = Image(path=sprite_path(r"43261e68-ecab-4142-8bd4-c0ef1a718941.png"), name="button_home.png")

    ButtonIconArrowShort = Image(path=sprite_path(r"72770d78-eda8-4da3-9acb-17783f75efa5.png"), name="button_icon_arrow_short.png")

    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"41488335-488f-4671-8535-7425ca55b8e9.png"), name="button_icon_arrow_short_disabled.png")

    ButtonIconCheckMark = Image(path=sprite_path(r"b0fd78a5-de52-4f21-8286-0dc002c377e8.png"), name="button_icon_check_mark.png")

    ButtonIconClose = Image(path=sprite_path(r"59776651-fa91-42b5-88f8-68d90a0c3457.png"), name="button_icon_close.png")

    ButtonNext = Image(path=sprite_path(r"be3cdc97-7184-40b4-a8c4-9517ffb26bcc.png"), name="button_next.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"4dab185b-98f0-4d34-938f-46c2f676afef.png"), name="button_next_no_icon.png")

    ButtonRetry = Image(path=sprite_path(r"f3b56370-7793-482f-b7ff-b1702621a6f0.png"), name="button_retry.png")

    ButtonSelect = Image(path=sprite_path(r"f36dfd02-77fe-4834-b30b-4e4e659dfbe9.png"), name="button_select.png")

    ButtonStart = Image(path=sprite_path(r"9a4cb769-3146-4c97-bd11-2244cb05883a.png"), name="button_start.png")

    ButtonToolbarHome = Image(path=sprite_path(r"972d36f3-00ae-4d94-95e7-a19a2ef15c41.png"), name="button_toolbar_home.png")

    CheckboxUnchecked = Image(path=sprite_path(r"f3cdd60d-d698-4228-92ff-7398a4e5c5b6.png"), name="checkbox_unchecked.png")

    ButtonToolbarHomeBinary = Image(path=sprite_path(r"2f68e457-4491-4ebc-b436-e3e63db92e14.png"), name="底部工具栏 首页按钮 二值化图片")

    ButtonToolbarMenuBinary = Image(path=sprite_path(r"bf6dcf21-2ffc-441f-82f3-59319f2313b1.png"), name="底部工具栏 菜单按钮 二值化图片")

    TextGameUpdate = Image(path=sprite_path(r"97b3f835-e94e-48ab-a8c3-dde980490a46.png"), name="text_game_update.png")

    TextNetworkError = Image(path=sprite_path(r"cf78f390-0309-494d-adfb-6d7ca45fd9f6.png"), name="text_network_error.png")

    ButtonOK = Image(path=sprite_path(r"8424ecdd-8857-4764-9fd0-d4bfa440c128.png"), name="OK 按钮")

    ButtonSelect2 = Image(path=sprite_path(r"5ebcde3b-f0fd-4e5d-b3de-ada8f0b5e03b.png"), name="選択する")


    pass
class Daily:
    
    ButonLinkData = Image(path=sprite_path(r"5d9c0c25-309b-4e27-8ada-76b07b7decf8.png"), name="buton_link_data.png")

    ButtonAssignmentPartial = Image(path=sprite_path(r"ee926611-b28b-4567-89a4-b4921f0de8bf.png"), name="button_assignment_partial.png")

    ButtonClaimAllNoIcon = Image(path=sprite_path(r"b9fe4a77-a620-4f47-a5ab-1e4ddfbd0da0.png"), name="button_claim_all_no_icon.png")

    ButtonContestChallenge = Image(path=sprite_path(r"52ee3086-6e66-44b4-90d8-00e93b317100.png"), name="button_contest_challenge.png")

    ButtonContestChallengeStart = Image(path=sprite_path(r"0f3e74a2-bead-4bb9-a1e6-6677d8ec9b0e.png"), name="button_contest_challenge_start.png")

    ButtonContestRanking = Image(path=sprite_path(r"64ca7742-aae2-4d08-9894-20102ecc72e0.png"), name="button_contest_ranking.png")

    ButtonContestStart = Image(path=sprite_path(r"dacf8bcd-6bae-45cf-a2b9-5417b7309ac6.png"), name="button_contest_start.png")

    ButtonDailyShop = Image(path=sprite_path(r"1929e8f0-17c9-4fb1-9ce8-7254641ad9df.png"), name="button_daily_shop.png")

    ButtonHomeCurrent = Image(path=sprite_path(r"3824f2f3-88c5-4334-b2e2-2ec18ea5d515.png"), name="button_home_current.png")

    ButtonIconPass = Image(path=sprite_path(r"7fd99882-2038-42b4-a1a8-5083e15f191b.png"), name="button_icon_pass.png")

    ButtonIconSkip = Image(path=sprite_path(r"c6c5369b-d289-43d5-aca8-7a42f83b4c64.png"), name="button_icon_skip.png")

    ButtonMission = Image(path=sprite_path(r"e13e7d57-6ec4-4545-890b-3ad5a5e9847b.png"), name="button_mission.png")

    ButtonPass = Image(path=sprite_path(r"84a8959d-f44c-4498-8490-0129f0b55be6.png"), name="button_pass.png")

    ButtonPassClaim = Image(path=sprite_path(r"175ca429-9e38-45be-8168-f4f3ef6c7c45.png"), name="button_pass_claim.png")

    ButtonPresentsPartial = Image(path=sprite_path(r"5806056a-168e-4c64-95c4-9ce722493634.png"), name="button_presents_partial.png")

    ButtonProduce = Image(path=sprite_path(r"5f36045c-7a87-4c55-8057-02c151ef15ae.png"), name="button_produce.png")

    ButtonShop = Image(path=sprite_path(r"c783725d-c043-4b53-a38e-f36136e0ed2f.png"), name="button_shop.png")

    ButtonShopCountAdd = Image(path=sprite_path(r"f36c4dbe-6dd0-42de-afb9-b55512ca029a.png"), name="button_shop_count_add.png")

    ButtonShopCountAddDisabled = Image(path=sprite_path(r"fdcb34be-e4e4-470c-82d0-8419e96be216.png"), name="button_shop_count_add_disabled.png")

    IconTitleDailyShop = Image(path=sprite_path(r"e9ee330d-dfca-440e-8b8c-0a3b4e8c8730.png"), name="日常商店标题图标")

    BoxHomeAssignment = HintBox(x1=16, y1=642, x2=127, y2=752, source_resolution=(720, 1280))

    BoxHomeAP = HintBox(x1=291, y1=4, x2=500, y2=82, source_resolution=(720, 1280))

    BoxHomeJewel = HintBox(x1=500, y1=7, x2=703, y2=82, source_resolution=(720, 1280))

    BoxHomeActivelyFunds = HintBox(x1=11, y1=517, x2=137, y2=637, source_resolution=(720, 1280))

    IconAssignKouchou = Image(path=sprite_path(r"4b32ef3e-f8b9-44d4-ae59-dc046a16df16.png"), name="icon_assign_kouchou.png")

    IconAssignMiniLive = Image(path=sprite_path(r"8ca70f36-71fa-4ffa-a6cb-7074ed0ac5d3.png"), name="icon_assign_mini_live.png")

    IconAssignOnlineLive = Image(path=sprite_path(r"896e61dc-c62f-4921-94c2-e0b06d062175.png"), name="icon_assign_online_live.png")

    IconAssignTitle = Image(path=sprite_path(r"0163bac4-7dc3-402e-9fe1-b2a06139ea85.png"), name="icon_assign_title.png")

    IconShopAp = Image(path=sprite_path(r"c8bc7a93-354a-4420-a49b-8eac554fcae0.png"), name="icon_shop_ap.png")

    IconShopMoney = Image(path=sprite_path(r"75d63b88-021b-433d-b702-87bdb6c17137.png"), name="icon_shop_money.png")

    IconShopTitle = Image(path=sprite_path(r"e07f6948-7983-4d22-8762-e6bce2edc16a.png"), name="icon_shop_title.png")

    IconTitleAssign = Image(path=sprite_path(r"7bc31506-df4f-4e46-85f9-275502377672.png"), name="icon_title_assign.png")

    IconTitlePass = Image(path=sprite_path(r"dabc24b3-0288-489f-9513-8b4b96f3fcda.png"), name="icon_title_pass.png")

    BoxApkUpdateDialogTitle = HintBox(x1=26, y1=905, x2=342, y2=967, source_resolution=(720, 1280))

    ButtonAssignmentShortenTime = Image(path=sprite_path(r"1652f06a-5417-49ef-8949-4854772d9ab7.png"), name="工作页面 短缩 时间")

    BoxMissonTabs = HintBox(x1=11, y1=929, x2=703, y2=1030, source_resolution=(720, 1280))

    TextActivityFundsMax = Image(path=sprite_path(r"d6862f6b-63ec-4d2c-bdf5-3f55dd2aa491.png"), name="text_activity_funds_max.png")

    TextAssignmentCompleted = Image(path=sprite_path(r"24f4c14a-b896-40c0-a4aa-75995d056ba5.png"), name="text_assignment_completed.png")

    TextContest = Image(path=sprite_path(r"e2b2a615-1437-4ffe-8aa7-f15653bdc048.png"), name="text_contest.png")

    TextContestLastOngoing = Image(path=sprite_path(r"ee289852-a6e8-4bb1-88bc-cec628b6f7bd.png"), name="text_contest_last_ongoing.png")

    TextContestNoMemory = Image(path=sprite_path(r"f137a9f1-fecb-461e-a5e0-29b5af7277b8.png"), name="text_contest_no_memory.png")

    TextContestOverallStats = Image(path=sprite_path(r"69d3c73e-5330-4b2b-8b4f-43343edc3d2d.png"), name="text_contest_overall_stats.png")

    TextShopPurchased = Image(path=sprite_path(r"5379e8ba-40be-4bd7-8e26-69aa6a0c0227.png"), name="text_shop_purchased.png")

    TextShopRecommended = Image(path=sprite_path(r"0da17cad-c612-4567-bd53-74713ca51241.png"), name="text_shop_recommended.png")

    TextTabShopAp = Image(path=sprite_path(r"c2755806-3698-4c8c-8eff-deb7d8dbf5ea.png"), name="text_tab_shop_ap.png")


    pass
class Shop:
    
    ItemLessonNote = Image(path=sprite_path(r"0949c622-9067-4f0d-bac2-3f938a1d2ed2.png"), name="レッスンノート")

    ItemVeteranNote = Image(path=sprite_path(r"b2af59e9-60e3-4d97-8c72-c7ba092113a3.png"), name="ベテランノート")

    ItemSupportEnhancementPt = Image(path=sprite_path(r"835489e2-b29b-426c-b4c9-3bb9f8eb6195.png"), name="サポート強化Pt 支援强化Pt")

    ItemSenseNoteVocal = Image(path=sprite_path(r"c5b7d67e-7260-4f08-a0e9-4d31ce9bbecf.png"), name="センスノート（ボーカル）感性笔记（声乐）")

    ItemSenseNoteDance = Image(path=sprite_path(r"0f7d581d-cea3-4039-9205-732e4cd29293.png"), name="センスノート（ダンス）感性笔记（舞蹈）")

    ItemSenseNoteVisual = Image(path=sprite_path(r"d3cc3323-51af-4882-ae12-49e7384b746d.png"), name="センスノート（ビジュアル）感性笔记（形象）")

    ItemLogicNoteVocal = Image(path=sprite_path(r"a1df3af1-a3e7-4521-a085-e4dc3cd1cc57.png"), name="ロジックノート（ボーカル）理性笔记（声乐）")

    ItemLogicNoteDance = Image(path=sprite_path(r"a9fcaf04-0c1f-4b0f-bb5b-ede9da96180f.png"), name="ロジックノート（ダンス）理性笔记（舞蹈）")

    ItemLogicNoteVisual = Image(path=sprite_path(r"c3f536d6-a04a-4651-b3f9-dd2c22593f7f.png"), name="ロジックノート（ビジュアル）理性笔记（形象）")

    ItemAnomalyNoteVocal = Image(path=sprite_path(r"eef25cf9-afd0-43b1-b9c5-fbd997bd5fe0.png"), name="アノマリーノート（ボーカル）非凡笔记（声乐）")

    ItemAnomalyNoteDance = Image(path=sprite_path(r"df991b42-ed8e-4f2c-bf0c-aa7522f147b6.png"), name="アノマリーノート（ダンス）非凡笔记（舞蹈）")

    ItemAnomalyNoteVisual = Image(path=sprite_path(r"9340b854-025c-40da-9387-385d38433bef.png"), name="アノマリーノート（ビジュアル）非凡笔记（形象）")

    ItemRechallengeTicket = Image(path=sprite_path(r"ea1ba124-9cb3-4427-969a-bacd47e7d920.png"), name="再挑戦チケット 重新挑战券")

    ItemRecordKey = Image(path=sprite_path(r"1926f2f9-4bd7-48eb-9eba-28ec4efb0606.png"), name="記録の鍵  解锁交流的物品")

    class IdolPiece:
        
        倉本千奈_WonderScale = Image(path=sprite_path(r"6720b6e8-ae80-4cc0-a885-518efe12b707.png"), name="倉本千奈 WonderScale 碎片")
    
        篠泽广_光景 = Image(path=sprite_path(r"afa06fdc-a345-4384-b25d-b16540830256.png"), name="篠泽广 光景 碎片")
    
        紫云清夏_TameLieOneStep = Image(path=sprite_path(r"278b7d9c-707e-4392-9677-74574b5cdf42.png"), name="紫云清夏 Tame-Lie-One-Step 碎片")
    
        葛城リーリヤ_白線 = Image(path=sprite_path(r"74ff07b3-d91c-4579-80cd-379ed7020622.png"), name="葛城リーリヤ 白線 碎片")
    
        姫崎薪波_cIclumsy_trick  = Image(path=sprite_path(r"a7f5abf1-982f-4a55-8d41-3ad6f56798e0.png"), name="姫崎薪波 cIclumsy trick 碎片")
    
        花海咲季_FightingMyWay = Image(path=sprite_path(r"2bc00520-0afe-40e5-8743-d33fc6b2945a.png"), name="花海咲季 FightingMyWay 碎片")
    
        藤田ことね_世界一可愛い私 = Image(path=sprite_path(r"135ee57a-d30d-4ba8-83f0-9f1681a49ff7.png"), name="藤田ことね 世界一可愛い私 碎片")
    
        花海佑芽_TheRollingRiceball = Image(path=sprite_path(r"d15959bf-d07b-4f07-948a-c0aeaf17756a.png"), name="花海佑芽 The Rolling Riceball 碎片")
    
        月村手毬_LunaSayMaybe = Image(path=sprite_path(r"868b97a9-492e-4712-b47f-82b97495b019.png"), name="月村手毬 Luna say maybe 碎片")
    
    
        pass

    pass
class Produce:
    
    BoxProduceOngoing = HintBox(x1=179, y1=937, x2=551, y2=1091, source_resolution=(720, 1280))

    ButtonAutoSet = Image(path=sprite_path(r"1da590ae-88c5-48dc-909a-3376eb88263d.png"), name="button_auto_set.png")

    ButtonProduce = Image(path=sprite_path(r"a7a4f890-85c2-49e2-860f-f0bfc75c14e8.png"), name="button_produce.png")

    ButtonProduceStart = Image(path=sprite_path(r"19639cb5-2e98-4960-9e0d-e8bb4e9110ba.png"), name="button_produce_start.png")

    ButtonRegular = Image(path=sprite_path(r"7dc99458-aac1-4a5f-9ebb-d552e6e8ac6c.png"), name="button_regular.png")

    CheckboxIconNoteBoost = Image(path=sprite_path(r"31dedaa5-9cdf-404a-845b-b4365a225e11.png"), name="checkbox_icon_note_boost.png")

    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"8294ae38-068a-4246-a7a4-2b5baf6da5af.png"), name="checkbox_icon_support_pt_boost.png")

    BoxModeButtons = HintBox(x1=7, y1=818, x2=713, y2=996, source_resolution=(720, 1280))

    ButtonPIdolOverview = Image(path=sprite_path(r"e88c9ad1-ec37-4fcd-b086-862e1e7ce8fd.png"), name="Pアイドルー覧  P偶像列表展示")

    BoxStepIndicator = HintBox(x1=4, y1=11, x2=405, y2=99, source_resolution=(720, 1280))

    BoxSetCountIndicator = HintBox(x1=17, y1=671, x2=119, y2=707, source_resolution=(720, 1280))

    PointProduceNextSet = HintPoint(x=702, y=832)

    PointProducePrevSet = HintPoint(x=14, y=832)

    IconPIdolLevel = Image(path=sprite_path(r"30a6f399-6999-4f04-bb77-651e0214112f.png"), name="P偶像卡上的等级图标")

    KbIdolOverviewName = HintBox(x1=140, y1=16, x2=615, y2=97, source_resolution=(720, 1280))

    ButtonResume = Image(path=sprite_path(r"ccbcb114-7f73-43d1-904a-3a7ae660c531.png"), name="再開する")

    BoxResumeDialogProduceType = HintBox(x1=186, y1=491, x2=541, y2=550, source_resolution=(720, 1280))

    BoxResumeDialogIdolTitle = HintBox(x1=194, y1=794, x2=523, y2=840, source_resolution=(720, 1280))

    RadioTextSkipCommu = Image(path=sprite_path(r"0896992f-cfb6-4cc2-b470-2425992ed2a1.png"), name="radio_text_skip_commu.png")

    TextAPInsufficient = Image(path=sprite_path(r"4883c564-f950-4a29-9f5f-6f924123cd22.png"), name="培育 AP 不足提示弹窗 标题")

    ButtonRefillAP = Image(path=sprite_path(r"eaba6ebe-f0df-4918-aee5-ef4e3ffedcf0.png"), name="确认恢复AP按钮")

    ScreenshotNoEnoughAp2 = Image(path=sprite_path(r"ea7917ec-fdbc-414d-96b1-26854cc5f404.png"), name="screenshot_no_enough_ap_2.png")

    TextRentAvailable = Image(path=sprite_path(r"d52e5c91-b4d7-4805-91b7-f29bc076dea8.png"), name="text_rent_available.png")


    pass
class InPurodyuusu:
    
    A = Image(path=sprite_path(r"2b437854-eae7-49c8-80fe-789de9ee6b0f.png"), name="A.png")

    AcquireBtnDisabled = Image(path=sprite_path(r"875d9096-9187-403b-a729-9fb72ac9123f.png"), name="acquire_btn_disabled.png")

    ButtonCancel = Image(path=sprite_path(r"4548bf14-dbd1-4743-b787-7daa2412a305.png"), name="button_cancel.png")

    ButtonComplete = Image(path=sprite_path(r"68e3aa48-1d57-4496-baba-256df8f01c45.png"), name="button_complete.png")

    ButtonFinalPracticeDance = Image(path=sprite_path(r"33909788-5afa-47df-940f-4703116115ff.png"), name="button_final_practice_dance.png")

    ButtonFinalPracticeVisual = Image(path=sprite_path(r"ccdc4dc0-4be8-423c-a166-4a929d312c98.png"), name="button_final_practice_visual.png")

    ButtonFinalPracticeVocal = Image(path=sprite_path(r"8fbc4800-3c6c-45d4-8601-c1b19842f9f1.png"), name="button_final_practice_vocal.png")

    ButtonFollowNoIcon = Image(path=sprite_path(r"643a29c7-1836-40a3-b7ee-f23fb403c8b6.png"), name="button_follow_no_icon.png")

    ButtonIconStudy = Image(path=sprite_path(r"cd4ceaaf-6dcc-4b3c-9726-656784f820f6.png"), name="button_icon_study.png")

    ButtonIconStudyVisual = Image(path=sprite_path(r"766fbd6a-6c81-485c-ba0a-76671643ea71.png"), name="button_icon_study_visual.png")

    ButtonLeave = Image(path=sprite_path(r"e57d49f8-33ae-459c-8e3f-e88744b43fdb.png"), name="button_leave.png")

    ButtonNextNoIcon = Image(path=sprite_path(r"79fca6cc-c4c7-4456-8cd0-9ad5af315a86.png"), name="button_next_no_icon.png")

    ButtonNotAcquire = Image(path=sprite_path(r"edc9ab24-4385-485b-85f8-0c8c0509ffaf.png"), name="button_not_acquire.png")

    ButtonRetry = Image(path=sprite_path(r"3dff4246-fec8-4148-973e-2ad0643d6f4d.png"), name="button_retry.png")

    ButtonTextActionOuting = Image(path=sprite_path(r"68acda8a-6dce-476e-87f8-a5ec48f1c407.png"), name="button_text_action_outing.png")

    ButtonTextAllowance = Image(path=sprite_path(r"ad154dfe-7c34-4e68-9c3c-d8c130c59a7e.png"), name="button_text_allowance.png")

    ButtonTextConsult = Image(path=sprite_path(r"6e854367-6a23-4b17-89bf-239f3d369570.png"), name="button_text_consult.png")

    IconClearBlue = Image(path=sprite_path(r"447026ec-32ad-4636-b55e-9fbbf2400774.png"), name="icon_clear_blue.png")

    IconTitleAllowance = Image(path=sprite_path(r"a1919da1-ce3e-44e1-9d84-bd26d596354f.png"), name="icon_title_allowance.png")

    IconTitleStudy = Image(path=sprite_path(r"fa8bb5c2-811e-4d28-992a-807e404817b6.png"), name="icon_title_study.png")

    LootboxSliverLock = Image(path=sprite_path(r"389ca18a-75a8-48a5-860f-1b9ff6700653.png"), name="lootbox_sliver_lock.png")

    LootBoxSkillCard = Image(path=sprite_path(r"edd65bf8-ec9c-4dce-81b4-8f336ffe02ea.png"), name="loot_box_skill_card.png")

    M = Image(path=sprite_path(r"361a36b1-2961-4873-88b3-1cb211ca3a5c.png"), name="M.png")

    BoxWeeksUntilExam = HintBox(x1=11, y1=8, x2=237, y2=196, source_resolution=(720, 1280))

    TextActionVocal = Image(path=sprite_path(r"d6b64759-26b7-45b1-bf8e-5c0d98611e0d.png"), name="Vo. レッスン")

    TextActionDance = Image(path=sprite_path(r"303cccc1-c674-4d3a-8c89-19ea729fdbef.png"), name="Da. レッスン")

    TextActionVisual = Image(path=sprite_path(r"cc8a495d-330d-447d-8a80-a8a6ecc409c5.png"), name="Vi. レッスン")

    BoxExamTop = HintBox(x1=5, y1=2, x2=712, y2=55, source_resolution=(720, 1280))

    PDrinkIcon = Image(path=sprite_path(r"4325745f-76a0-4d1c-bb1f-e956a6622e91.png"), name="p_drink_icon.png")

    PItemIconColorful = Image(path=sprite_path(r"74478807-ad6b-4fe8-b279-98caaf1cbed8.png"), name="p_item_icon_colorful.png")

    PSkillCardIconBlue = Image(path=sprite_path(r"bb1a9e55-7ec9-4931-a15f-2272a0ca52bb.png"), name="p_skill_card_icon_blue.png")

    PSkillCardIconColorful = Image(path=sprite_path(r"d16cb1bb-7000-4cd7-a797-eb1026adc505.png"), name="p_skill_card_icon_colorful.png")

    Rest = Image(path=sprite_path(r"ada9ad5e-b0f6-455f-a358-840b0583b509.png"), name="rest.png")

    RestConfirmBtn = Image(path=sprite_path(r"595a1bfc-a020-4611-a326-976ff5e671cd.png"), name="rest_confirm_btn.png")

    ButtonIconOuting = Image(path=sprite_path(r"8ded6c98-85ea-4858-a66d-4fc8caecb7c5.png"), name="行动按钮图标 外出（おでかけ）")

    BoxGoalClearNext = HintBox(x1=79, y1=503, x2=157, y2=532, source_resolution=(720, 1280))

    BoxLessonCards5_1 = HintBox(x1=16, y1=882, x2=208, y2=1136, source_resolution=(720, 1280))

    BoxNoSkillCard = HintBox(x1=180, y1=977, x2=529, y2=1026, source_resolution=(720, 1280))

    TitleIconOuting = Image(path=sprite_path(r"ee4e512b-4982-49b6-9c71-31984b58e1d0.png"), name="外出（おでかけ）页面 标题图标")

    BoxPDrinkMaxConfirmTitle = HintBox(x1=46, y1=829, x2=270, y2=876, source_resolution=(720, 1280))

    BoxSelectPStuff = HintBox(x1=62, y1=558, x2=655, y2=716, source_resolution=(720, 1280))

    BoxSelectPStuffComfirm = HintBox(x1=256, y1=1064, x2=478, y2=1128, source_resolution=(720, 1280))

    BoxSkillCardAcquired = HintBox(x1=194, y1=712, x2=528, y2=765, source_resolution=(720, 1280))

    BoxSkillCardEnhaced = HintBox(x1=49, y1=948, x2=676, y2=1106, source_resolution=(720, 1280))

    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"b38f78cb-9966-4cfd-9758-54e4597c9608.png"), name="screenshot_skill_card_enhance_dialog.png")

    IconTitleSkillCardEnhance = Image(path=sprite_path(r"79abd239-5eed-4195-9fa8-d729daa874ca.png"), name="技能卡强化 标题 图标")

    ButtonEnhance = Image(path=sprite_path(r"da439e8c-3b74-4371-9657-0736d826c7d1.png"), name="技能卡 强化按钮")

    T = Image(path=sprite_path(r"16fbc93d-b294-4001-b4e9-ee2af181415f.png"), name="睡意卡字母 T（眠気）")

    IconSp = Image(path=sprite_path(r"d982d2b5-4bc0-4ae9-a516-f29c2848d64b.png"), name="SP 课程图标")

    BoxCommuEventButtonsArea = HintBox(x1=14, y1=412, x2=703, y2=1089, source_resolution=(720, 1280))

    TextSelfStudyVocal = Image(path=sprite_path(r"c78c38cc-7b61-4dc4-820d-0a5b684ef52e.png"), name="文化课事件 自习 声乐")

    TextSelfStudyDance = Image(path=sprite_path(r"83d0a033-466c-463a-bb8c-be0f2953e9b2.png"), name="文化课事件 自习 舞蹈")

    TextSelfStudyVisual = Image(path=sprite_path(r"4695f96b-c4f5-4bb6-a021-a13b6ceb2883.png"), name="文化课事件 自习 形象")

    TextAsariProduceEnd = Image(path=sprite_path(r"c1f57641-e0e5-4365-8c7b-0dfba908f85c.png"), name="text_asari_produce_end.png")

    TextButtonExamSkipTurn = Image(path=sprite_path(r"6d5c62ce-7fc3-467c-a3c3-dffc2966f647.png"), name="text_button_exam_skip_turn.png")

    TextClearUntil = Image(path=sprite_path(r"a4d330b0-3365-4db8-8091-3c131473dae5.png"), name="text_clear_until.png")

    TextDance = Image(path=sprite_path(r"9c457152-bba0-440c-8e7c-9b9f0c4cede2.png"), name="text_dance.png")

    TextFinalProduceRating = Image(path=sprite_path(r"ec434fc4-5a05-4e12-b430-70546b974152.png"), name="text_final_produce_rating.png")

    TextOneWeekRemaining = Image(path=sprite_path(r"b08b7528-0748-47b8-a159-494df696783a.png"), name="text_one_week_remaining.png")

    TextPerfectUntil = Image(path=sprite_path(r"2c5fe23e-c24d-4f5a-9cbd-a141ea2fbcba.png"), name="text_perfect_until.png")

    TextPleaseSelectPDrink = Image(path=sprite_path(r"80b0072b-ef96-47a9-aca7-a7b1ebf96619.png"), name="text_please_select_p_drink.png")

    TextPDiary = Image(path=sprite_path(r"b4019456-ba10-41d0-a1cf-18ef729568f3.png"), name="text_p_diary.png")

    TextPDrinkMax = Image(path=sprite_path(r"7f08080a-2f1e-46aa-928b-88bdfee1077e.png"), name="text_p_drink_max.png")

    TextSenseiTipConsult = Image(path=sprite_path(r"26de2ce1-941f-4b06-bd24-2a2f183ff7d6.png"), name="text_sensei_tip_consult.png")

    TextSenseiTipDance = Image(path=sprite_path(r"e46503a0-92cd-4aac-9a91-59a8502a6d07.png"), name="text_sensei_tip_dance.png")

    TextSenseiTipRest = Image(path=sprite_path(r"01b62cd0-b778-4776-b921-4da04c6de99f.png"), name="text_sensei_tip_rest.png")

    TextSenseiTipVisual = Image(path=sprite_path(r"bb9005be-867a-4769-bdb3-8f6e785f6577.png"), name="text_sensei_tip_visual.png")

    TextSenseiTipVocal = Image(path=sprite_path(r"17b3bc24-acfe-4e2f-aa76-0f5369f2c62d.png"), name="text_sensei_tip_vocal.png")

    TextSkipTurnDialog = Image(path=sprite_path(r"8faa6747-a3a8-46eb-99e1-64cae1536288.png"), name="text_skip_turn_dialog.png")

    TextVisual = Image(path=sprite_path(r"71c2de9c-2eb5-459f-b829-0b78967ec7e4.png"), name="text_visual.png")

    class Action:
        
        ActionStudy = Image(path=sprite_path(r"d1b6cb48-3c84-40c7-a7e9-c08cdb5bfbb5.png"), name="action_study.png")
    
        PDorinkuBg = Image(path=sprite_path(r"37e1b552-ef87-43c9-b4cb-a374ade47924.png"), name="p_dorinku_bg.png")
    
        PDorinkuBgMask = Image(path=sprite_path(r"e0ae2955-6afc-44f3-bc86-03dbf113af02.png"), name="p_dorinku_bg_mask.png")
    
        PItem = Image(path=sprite_path(r"4705ae92-ab52-4b5b-b289-6a17cd33ab79.png"), name="p_item.png")
    
        VocalWhiteBg = Image(path=sprite_path(r"69d46fc0-1ed8-4609-a0ff-50b3654d858b.png"), name="vocal_white_bg.png")
    
    
        pass

    pass